==> qt-creator-opensource-src-4.7.2.zip: qt-creator-opensource-src-4.7.2/src/plugins/qmldesigner/switchsplittabwidget.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QWidget>

QT_BEGIN_NAMESPACE
class QTabBar;
class QSplitter;
class QPushButton;
QT_END_NAMESPACE

namespace QmlDesigner {
class SwitchSplitTabWidget : public QWidget
{
    Q_OBJECT
    enum Mode {
        SplitMode,
        TabMode
    };
public:
    explicit SwitchSplitTabWidget(QWidget *parent = nullptr);
    int count() const;
    QWidget *currentWidget() const;

    int addTab(QWidget *widget, const QString &label);
    QWidget *takeTabWidget(const int index);
    void switchTo(QWidget *widget);

protected:
    bool event(QEvent* event) override;

private:
    void updateSplitterSizes(int index = -1);
    void updateSplitButtons();
    void selectFakeTab();
    Mode mode();

    QSplitter *m_splitter = nullptr;
    QTabBar *m_tabBar = nullptr;
    QWidget *m_tabBarBackground = nullptr;
    const int fakeTab = 1;
    bool m_splittSizesAreDirty = true;
};
} // namespace QmlDesigner

==> qt-creator-opensource-src-4.12.4.zip: qt-creator-opensource-src-4.12.4/src/plugins/qmldesigner/switchsplittabwidget.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QWidget>

QT_BEGIN_NAMESPACE
class QTabBar;
class QSplitter;
class QPushButton;
QT_END_NAMESPACE

namespace QmlDesigner {
class SwitchSplitTabWidget : public QWidget
{
    Q_OBJECT

    enum Mode { SplitMode, TabMode };

public:
    explicit SwitchSplitTabWidget(QWidget *parent = nullptr);
    int count() const;
    QWidget *currentWidget() const;

    int addTab(QWidget *widget, const QString &label);
    QWidget *takeTabWidget(const int index);
    void switchTo(QWidget *widget);

private:
    void updateSplitterSizes(int index = -1);
    void updateSplitButtons();
    void selectFakeTab();
    Mode mode() const;

    QSplitter *m_splitter = nullptr;
    QTabBar *m_tabBar = nullptr;
    QWidget *m_tabBarBackground = nullptr;
    const int fakeTab = 1;
};
} // namespace QmlDesigner
